==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/af_ZA.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Kon nie e-pos aan die volgende gebruikers stuur nie: %s",
    "Turned on maintenance mode" : "Instandhouding aangeskakel",
    "Turned off maintenance mode" : "Instandhouding uitgeskakel",
    "Updated database" : "Databasis opgedateer",
    "Checked database schema update" : "Databasis skema opdatering nagegaan",
    "Checked database schema update for apps" : "Databasis skema opdatering nagegaan vir sagteware",
    "Updated \"%s\" to %s" : "\"%s\" opgedateer na %s",
    "Repair warning: " : "Herstel waarskuwing:",
    "Repair error: " : "Herstel fout:",
    "No image or file provided" : "Geen prent of lêer voorsien",
    "Unknown filetype" : "Onbekende lêertipe",
    "Invalid image" : "Ongeldige prent",
    "No temporary profile picture available, try again" : "Geen tydelike profiel foto beskikbaar nie, probeer weer",
    "No crop data provided" : "Geen \"crop\" data verskaf",
    "Sunday" : "Sondag",
    "Monday" : "Maandag",
    "Tuesday" : "Dinsdag",
    "Wednesday" : "Woensdag",
    "Thursday" : "Donderdag",
    "Friday" : "Vrydag",
    "Saturday" : "Saterdag",
    "January" : "Januarie",
    "February" : "Februarie",
    "March" : "Maart",
    "April" : "April",
    "May" : "Mei",
    "June" : "Junie",
    "July" : "Julie",
    "August" : "Augustus",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Settings" : "Instellings",
    "Saving..." : "Stoor...",
    "seconds ago" : "sekondes gelede",
    "Couldn't send reset email. Please contact your administrator." : "Die herstel epos kon nie gestuur word nie. Kontak asseblief die stelsel administrateur.",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Die \"link\" vir die herstel van jou wagwoord is na jou epos gestuur. As jy dit nie binne 'n redelike tyd ontvang nie, soek deur jou \"spam/junk\" omslagte.<br>As dit nie daar is nie vra jou administrateur vir hulp.",
    "I know what I'm doing" : "Ek weet wat ek doen",
    "Password can not be changed. Please contact your administrator." : "Wagwoord kan nie verander word nie. Kontak asseblief jou stelsel administrateur.",
    "No" : "Nee",
    "Yes" : "Ja",
    "Choose" : "Kies",
    "Ok" : "OK",
    "One file conflict" : "Een lêer konflik",
    "New Files" : "Nuwe lêers",
    "Already existing files" : "Bestaande lêers",
    "Which files do you want to keep?" : "Watse lêers wil jy hou?",
    "Cancel" : "Kanselleer",
    "Continue" : "Gaan voort",
    "Very weak password" : "Baie swak wagwoord",
    "Weak password" : "Swak wagwoord",
    "So-so password" : "So-so wagwoord",
    "Good password" : "Goeie wagwoord",
    "Strong password" : "Sterk wagwoord",
    "Shared" : "Gedeel",
    "Error" : "Fout",
    "Error while sharing" : "Deel veroorsaak fout",
    "Error while unsharing" : "Deel terugneem veroorsaak fout",
    "Error while changing permissions" : "Fout met verandering van regte",
    "Error setting expiration date" : "Fout met opstel van verval datum",
    "Set expiration date" : "Stel verval datum",
    "Expiration date" : "Verval datum",
    "Sending ..." : "Stuur ...",
    "Email sent" : "E-pos gestuur",
    "Resharing is not allowed" : "Herdeling is nie toegelaat nie ",
    "Password protect" : "Beskerm met Wagwoord",
    "Password" : "Wagwoord",
    "Email link to person" : "E-pos aan persoon",
    "Send" : "Stuur",
    "Shared with you and the group {group} by {owner}" : "Met jou en die groep {group} gedeel deur {owner}",
    "Shared with you by {owner}" : "Met jou gedeel deur {owner}",
    "Shared in {item} with {user}" : "Gedeel in {item} met {user}",
    "group" : "groep",
    "Unshare" : "Deel terug neem",
    "can edit" : "kan wysig",
    "create" : "skep",
    "delete" : "uitvee",
    "access control" : "toegang beheer",
    "Share" : "Deel",
    "Warning" : "Waarskuwing",
    "The object type is not specified." : "Hierdie objek tipe is nie gespesifiseer nie.",
    "Add" : "Voeg by",
    "The update was successful. Redirecting you to ownCloud now." : "Die opdatering was suksesvol. Jy word nou aan ownCloud terug gelei.",
    "%s password reset" : "%s wagwoord herstel",
    "Use the following link to reset your password: {link}" : "Gebruik die volgende skakel om jou wagwoord te herstel: {link}",
    "New password" : "Nuwe wagwoord",
    "Reset password" : "Herstel wagwoord",
    "Personal" : "Persoonlik",
    "Users" : "Gebruikers",
    "Apps" : "Toepassings",
    "Admin" : "Admin",
    "Help" : "Hulp",
    "Access forbidden" : "Toegang verbode",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jou data gids en lêers is moontlik toeganklik vanaf die internet omdat die .htaccess lêer nie werk nie.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Vir inligting oor hoe om jou bediener behoorlik op te stel, sien asseblief die<a href=\"%s\" target=\"_blank\">dokumentasie</a>.",
    "Create an <strong>admin account</strong>" : "Skep `n <strong>admin-rekening</strong>",
    "Username" : "Gebruikersnaam",
    "Data folder" : "Data omslag",
    "Configure the database" : "Stel databasis op",
    "Database user" : "Databasis-gebruiker",
    "Database password" : "Databasis-wagwoord",
    "Database name" : "Databasis naam",
    "Database tablespace" : "Databasis tabelspasie",
    "Database host" : "Databasis gasheer",
    "Finish setup" : "Maak opstelling klaar",
    "Log out" : "Teken uit",
    "Log in" : "Teken aan",
    "remember" : "onthou",
    "Alternative Logins" : "Alternatiewe aantekeninge",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Halo daar,<br><br>wou jou net laat weet dat %s <strong>%s</strong> met jou gedeel het.<br><a href=\"%s\">Sien alles!</a><br><br>"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/af_ZA.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Kon nie e-pos aan die volgende gebruikers stuur nie: %s",
    "Turned on maintenance mode" : "Instandhouding aangeskakel",
    "Turned off maintenance mode" : "Instandhouding uitgeskakel",
    "Updated database" : "Databasis opgedateer",
    "Checked database schema update" : "Databasis skema opdatering nagegaan",
    "Checked database schema update for apps" : "Databasis skema opdatering nagegaan vir sagteware",
    "Updated \"%s\" to %s" : "\"%s\" opgedateer na %s",
    "Repair warning: " : "Herstel waarskuwing:",
    "Repair error: " : "Herstel fout:",
    "No image or file provided" : "Geen prent of lêer voorsien",
    "Unknown filetype" : "Onbekende lêertipe",
    "Invalid image" : "Ongeldige prent",
    "No temporary profile picture available, try again" : "Geen tydelike profiel foto beskikbaar nie, probeer weer",
    "No crop data provided" : "Geen \"crop\" data verskaf",
    "%s password reset" : "%s wagwoord herstel",
    "Couldn't send reset email. Please contact your administrator." : "Die herstel epos kon nie gestuur word nie. Kontak asseblief die stelsel administrateur.",
    "Sunday" : "Sondag",
    "Monday" : "Maandag",
    "Tuesday" : "Dinsdag",
    "Wednesday" : "Woensdag",
    "Thursday" : "Donderdag",
    "Friday" : "Vrydag",
    "Saturday" : "Saterdag",
    "January" : "Januarie",
    "February" : "Februarie",
    "March" : "Maart",
    "April" : "April",
    "May" : "Mei",
    "June" : "Junie",
    "July" : "Julie",
    "August" : "Augustus",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Settings" : "Instellings",
    "Saving..." : "Stoor...",
    "seconds ago" : "sekondes gelede",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Die \"link\" vir die herstel van jou wagwoord is na jou epos gestuur. As jy dit nie binne 'n redelike tyd ontvang nie, soek deur jou \"spam/junk\" omslagte.<br>As dit nie daar is nie vra jou administrateur vir hulp.",
    "I know what I'm doing" : "Ek weet wat ek doen",
    "Password can not be changed. Please contact your administrator." : "Wagwoord kan nie verander word nie. Kontak asseblief jou stelsel administrateur.",
    "No" : "Nee",
    "Yes" : "Ja",
    "Choose" : "Kies",
    "Ok" : "OK",
    "One file conflict" : "Een lêer konflik",
    "New Files" : "Nuwe lêers",
    "Already existing files" : "Bestaande lêers",
    "Which files do you want to keep?" : "Watse lêers wil jy hou?",
    "Cancel" : "Kanselleer",
    "Continue" : "Gaan voort",
    "Very weak password" : "Baie swak wagwoord",
    "Weak password" : "Swak wagwoord",
    "So-so password" : "So-so wagwoord",
    "Good password" : "Goeie wagwoord",
    "Strong password" : "Sterk wagwoord",
    "Shared" : "Gedeel",
    "Error" : "Fout",
    "Error while sharing" : "Deel veroorsaak fout",
    "Error while unsharing" : "Deel terugneem veroorsaak fout",
    "Error setting expiration date" : "Fout met opstel van verval datum",
    "Set expiration date" : "Stel verval datum",
    "Expiration date" : "Verval datum",
    "Sending ..." : "Stuur ...",
    "Email sent" : "E-pos gestuur",
    "Resharing is not allowed" : "Herdeling is nie toegelaat nie ",
    "Password protect" : "Beskerm met Wagwoord",
    "Password" : "Wagwoord",
    "Email link to person" : "E-pos aan persoon",
    "Send" : "Stuur",
    "Shared with you and the group {group} by {owner}" : "Met jou en die groep {group} gedeel deur {owner}",
    "Shared with you by {owner}" : "Met jou gedeel deur {owner}",
    "group" : "groep",
    "Unshare" : "Deel terug neem",
    "can edit" : "kan wysig",
    "create" : "skep",
    "delete" : "uitvee",
    "access control" : "toegang beheer",
    "Share" : "Deel",
    "Warning" : "Waarskuwing",
    "The object type is not specified." : "Hierdie objek tipe is nie gespesifiseer nie.",
    "Add" : "Voeg by",
    "The update was successful. Redirecting you to ownCloud now." : "Die opdatering was suksesvol. Jy word nou aan ownCloud terug gelei.",
    "Personal" : "Persoonlik",
    "Users" : "Gebruikers",
    "Apps" : "Toepassings",
    "Admin" : "Admin",
    "Help" : "Hulp",
    "Access forbidden" : "Toegang verbode",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jou data gids en lêers is moontlik toeganklik vanaf die internet omdat die .htaccess lêer nie werk nie.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Vir inligting oor hoe om jou bediener behoorlik op te stel, sien asseblief die<a href=\"%s\" target=\"_blank\">dokumentasie</a>.",
    "Create an <strong>admin account</strong>" : "Skep `n <strong>admin-rekening</strong>",
    "Username" : "Gebruikersnaam",
    "Data folder" : "Data omslag",
    "Configure the database" : "Stel databasis op",
    "Database user" : "Databasis-gebruiker",
    "Database password" : "Databasis-wagwoord",
    "Database name" : "Databasis naam",
    "Database tablespace" : "Databasis tabelspasie",
    "Database host" : "Databasis gasheer",
    "Finish setup" : "Maak opstelling klaar",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Halo daar,<br><br>wou jou net laat weet dat %s <strong>%s</strong> met jou gedeel het.<br><a href=\"%s\">Sien alles!</a><br><br>",
    "Log out" : "Teken uit",
    "Log in" : "Teken aan",
    "Alternative Logins" : "Alternatiewe aantekeninge",
    "Use the following link to reset your password: {link}" : "Gebruik die volgende skakel om jou wagwoord te herstel: {link}",
    "New password" : "Nuwe wagwoord",
    "Reset password" : "Herstel wagwoord"
},
"nplurals=2; plural=(n != 1);");
